
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({"convert_from": "convertFrom", "convert_to": "convertTo"})
class MapExtensionsJapaneseCharacterConversion(BaseModel):
    """MapExtensionsJapaneseCharacterConversion

    :param convert_from: convert_from, defaults to None
    :type convert_from: str, optional
    :param convert_to: convert_to, defaults to None
    :type convert_to: str, optional
    """

    def __init__(
        self, convert_from: str = SENTINEL, convert_to: str = SENTINEL, **kwargs
    ):
        """MapExtensionsJapaneseCharacterConversion

        :param convert_from: convert_from, defaults to None
        :type convert_from: str, optional
        :param convert_to: convert_to, defaults to None
        :type convert_to: str, optional
        """
        if convert_from is not SENTINEL:
            self.convert_from = convert_from
        if convert_to is not SENTINEL:
            self.convert_to = convert_to
        self._kwargs = kwargs




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .execution_count_account_group_simple_expression import (
    ExecutionCountAccountGroupSimpleExpression,
)
from .execution_count_account_group_grouping_expression import (
    ExecutionCountAccountGroupGroupingExpression,
)


class ExecutionCountAccountGroupExpressionGuard(OneOfBaseModel):
    class_list = {
        "ExecutionCountAccountGroupSimpleExpression": ExecutionCountAccountGroupSimpleExpression,
        "ExecutionCountAccountGroupGroupingExpression": ExecutionCountAccountGroupGroupingExpression,
    }


ExecutionCountAccountGroupExpression = Union[
    ExecutionCountAccountGroupSimpleExpression,
    ExecutionCountAccountGroupGroupingExpression,
]




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .environment_connection_field_extension_summary_expression import (
    EnvironmentConnectionFieldExtensionSummaryExpression,
    EnvironmentConnectionFieldExtensionSummaryExpressionGuard,
)
from .environment_connection_field_extension_summary_simple_expression import (
    EnvironmentConnectionFieldExtensionSummarySimpleExpression,
)
from .environment_connection_field_extension_summary_grouping_expression import (
    EnvironmentConnectionFieldExtensionSummaryGroupingExpression,
)


@JsonMap({})
class EnvironmentConnectionFieldExtensionSummaryQueryConfigQueryFilter(BaseModel):
    """EnvironmentConnectionFieldExtensionSummaryQueryConfigQueryFilter

    :param expression: expression
    :type expression: EnvironmentConnectionFieldExtensionSummaryExpression
    """

    def __init__(
        self, expression: EnvironmentConnectionFieldExtensionSummaryExpression, **kwargs
    ):
        """EnvironmentConnectionFieldExtensionSummaryQueryConfigQueryFilter

        :param expression: expression
        :type expression: EnvironmentConnectionFieldExtensionSummaryExpression
        """
        self.expression = (
            EnvironmentConnectionFieldExtensionSummaryExpressionGuard.return_one_of(
                expression
            )
        )
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class EnvironmentConnectionFieldExtensionSummaryQueryConfig(BaseModel):
    """EnvironmentConnectionFieldExtensionSummaryQueryConfig

    :param query_filter: query_filter
    :type query_filter: EnvironmentConnectionFieldExtensionSummaryQueryConfigQueryFilter
    """

    def __init__(
        self,
        query_filter: EnvironmentConnectionFieldExtensionSummaryQueryConfigQueryFilter,
        **kwargs,
    ):
        """EnvironmentConnectionFieldExtensionSummaryQueryConfig

        :param query_filter: query_filter
        :type query_filter: EnvironmentConnectionFieldExtensionSummaryQueryConfigQueryFilter
        """
        self.query_filter = self._define_object(
            query_filter,
            EnvironmentConnectionFieldExtensionSummaryQueryConfigQueryFilter,
        )
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .processing_group_default_routing import ProcessingGroupDefaultRouting
from .processing_group_document_based_routing import ProcessingGroupDocumentBasedRouting
from .processing_group_partner_based_routing import ProcessingGroupPartnerBasedRouting
from .processing_group_trading_partners import ProcessingGroupTradingPartners


@JsonMap(
    {
        "default_routing": "DefaultRouting",
        "document_routing": "DocumentRouting",
        "partner_routing": "PartnerRouting",
        "trading_partners": "TradingPartners",
        "component_id": "componentId",
        "component_name": "componentName",
        "folder_id": "folderId",
        "folder_name": "folderName",
        "branch_id": "branchId",
        "branch_name": "branchName",
    }
)
class TradingPartnerProcessingGroup(BaseModel):
    """TradingPartnerProcessingGroup

    :param default_routing: default_routing, defaults to None
    :type default_routing: ProcessingGroupDefaultRouting, optional
    :param document_routing: document_routing, defaults to None
    :type document_routing: ProcessingGroupDocumentBasedRouting, optional
    :param partner_routing: partner_routing, defaults to None
    :type partner_routing: ProcessingGroupPartnerBasedRouting, optional
    :param trading_partners: trading_partners, defaults to None
    :type trading_partners: ProcessingGroupTradingPartners, optional
    :param component_id: component_id, defaults to None
    :type component_id: str, optional
    :param component_name: component_name, defaults to None
    :type component_name: str, optional
    :param deleted: deleted, defaults to None
    :type deleted: bool, optional
    :param description: description, defaults to None
    :type description: str, optional
    :param folder_id: folder_id, defaults to None
    :type folder_id: int, optional
    :param folder_name: folder_name, defaults to None
    :type folder_name: str, optional
    :param branch_id: branch_id, defaults to None
    :type branch_id: str, optional
    :param branch_name: branch_name, defaults to None
    :type branch_name: str, optional
    """

    def __init__(
        self,
        default_routing: ProcessingGroupDefaultRouting = SENTINEL,
        document_routing: ProcessingGroupDocumentBasedRouting = SENTINEL,
        partner_routing: ProcessingGroupPartnerBasedRouting = SENTINEL,
        trading_partners: ProcessingGroupTradingPartners = SENTINEL,
        component_id: str = SENTINEL,
        component_name: str = SENTINEL,
        deleted: bool = SENTINEL,
        description: str = SENTINEL,
        folder_id: int = SENTINEL,
        folder_name: str = SENTINEL,
        branch_id: str = SENTINEL,
        branch_name: str = SENTINEL,
        **kwargs,
    ):
        """TradingPartnerProcessingGroup

        :param default_routing: default_routing, defaults to None
        :type default_routing: ProcessingGroupDefaultRouting, optional
        :param document_routing: document_routing, defaults to None
        :type document_routing: ProcessingGroupDocumentBasedRouting, optional
        :param partner_routing: partner_routing, defaults to None
        :type partner_routing: ProcessingGroupPartnerBasedRouting, optional
        :param trading_partners: trading_partners, defaults to None
        :type trading_partners: ProcessingGroupTradingPartners, optional
        :param component_id: component_id, defaults to None
        :type component_id: str, optional
        :param component_name: component_name, defaults to None
        :type component_name: str, optional
        :param deleted: deleted, defaults to None
        :type deleted: bool, optional
        :param description: description, defaults to None
        :type description: str, optional
        :param folder_id: folder_id, defaults to None
        :type folder_id: int, optional
        :param folder_name: folder_name, defaults to None
        :type folder_name: str, optional
        :param branch_id: branch_id, defaults to None
        :type branch_id: str, optional
        :param branch_name: branch_name, defaults to None
        :type branch_name: str, optional
        """
        if default_routing is not SENTINEL:
            self.default_routing = self._define_object(
                default_routing, ProcessingGroupDefaultRouting
            )
        if document_routing is not SENTINEL:
            self.document_routing = self._define_object(
                document_routing, ProcessingGroupDocumentBasedRouting
            )
        if partner_routing is not SENTINEL:
            self.partner_routing = self._define_object(
                partner_routing, ProcessingGroupPartnerBasedRouting
            )
        if trading_partners is not SENTINEL:
            self.trading_partners = self._define_object(
                trading_partners, ProcessingGroupTradingPartners
            )
        if component_id is not SENTINEL:
            self.component_id = component_id
        if component_name is not SENTINEL:
            self.component_name = component_name
        if deleted is not SENTINEL:
            self.deleted = deleted
        if description is not SENTINEL:
            self.description = description
        if folder_id is not SENTINEL:
            self.folder_id = folder_id
        if folder_name is not SENTINEL:
            self.folder_name = folder_name
        if branch_id is not SENTINEL:
            self.branch_id = branch_id
        if branch_name is not SENTINEL:
            self.branch_name = branch_name
        self._kwargs = kwargs




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .component_info import ComponentInfo


@JsonMap({"component_info": "componentInfo", "package_id": "packageId"})
class PackagedComponentManifest(BaseModel):
    """PackagedComponentManifest

    :param component_info: component_info, defaults to None
    :type component_info: List[ComponentInfo], optional
    :param package_id: The ID of the packaged component.
    :type package_id: str
    """

    def __init__(
        self, package_id: str, component_info: List[ComponentInfo] = SENTINEL, **kwargs
    ):
        """PackagedComponentManifest

        :param component_info: component_info, defaults to None
        :type component_info: List[ComponentInfo], optional
        :param package_id: The ID of the packaged component.
        :type package_id: str
        """
        if component_info is not SENTINEL:
            self.component_info = self._define_list(component_info, ComponentInfo)
        self.package_id = package_id
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .listener_status_expression import (
    ListenerStatusExpression,
    ListenerStatusExpressionGuard,
)
from .listener_status_simple_expression import ListenerStatusSimpleExpression
from .listener_status_grouping_expression import ListenerStatusGroupingExpression


@JsonMap({})
class ListenerStatusQueryConfigQueryFilter(BaseModel):
    """ListenerStatusQueryConfigQueryFilter

    :param expression: expression
    :type expression: ListenerStatusExpression
    """

    def __init__(self, expression: ListenerStatusExpression, **kwargs):
        """ListenerStatusQueryConfigQueryFilter

        :param expression: expression
        :type expression: ListenerStatusExpression
        """
        self.expression = ListenerStatusExpressionGuard.return_one_of(expression)
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class ListenerStatusQueryConfig(BaseModel):
    """ListenerStatusQueryConfig

    :param query_filter: query_filter
    :type query_filter: ListenerStatusQueryConfigQueryFilter
    """

    def __init__(self, query_filter: ListenerStatusQueryConfigQueryFilter, **kwargs):
        """ListenerStatusQueryConfig

        :param query_filter: query_filter
        :type query_filter: ListenerStatusQueryConfigQueryFilter
        """
        self.query_filter = self._define_object(
            query_filter, ListenerStatusQueryConfigQueryFilter
        )
        self._kwargs = kwargs




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .map_extensions_function_mapping import MapExtensionsFunctionMapping


@JsonMap({"mapping": "Mapping"})
class MapExtensionsFunctionMappings(BaseModel):
    """Defines the mapping of inputs and outputs for the user-defined function and each function step. It uses the following attributes:

     1. fromFunction - represents the function ID from which you are mapping.
     2. fromKey - represents the function's output key from which you are mapping.
     3. toFunction - represents the function ID to which you are mapping.
     4. toKey - represents the function's input key to which you are mapping.

    :param mapping: mapping, defaults to None
    :type mapping: List[MapExtensionsFunctionMapping], optional
    """

    def __init__(
        self, mapping: List[MapExtensionsFunctionMapping] = SENTINEL, **kwargs
    ):
        """Defines the mapping of inputs and outputs for the user-defined function and each function step. It uses the following attributes:

         1. fromFunction - represents the function ID from which you are mapping.
         2. fromKey - represents the function's output key from which you are mapping.
         3. toFunction - represents the function ID to which you are mapping.
         4. toKey - represents the function's input key to which you are mapping.

        :param mapping: mapping, defaults to None
        :type mapping: List[MapExtensionsFunctionMapping], optional
        """
        if mapping is not SENTINEL:
            self.mapping = self._define_list(mapping, MapExtensionsFunctionMapping)
        self._kwargs = kwargs




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .integration_pack_simple_expression import IntegrationPackSimpleExpression
from .integration_pack_grouping_expression import IntegrationPackGroupingExpression


class IntegrationPackExpressionGuard(OneOfBaseModel):
    class_list = {
        "IntegrationPackSimpleExpression": IntegrationPackSimpleExpression,
        "IntegrationPackGroupingExpression": IntegrationPackGroupingExpression,
    }


IntegrationPackExpression = Union[
    IntegrationPackSimpleExpression, IntegrationPackGroupingExpression
]




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..merge_request import MergeRequestService
from ...models import (
    MergeRequest,
    MergeRequestBulkResponse,
    MergeRequestBulkRequest,
    MergeRequestQueryResponse,
    MergeRequestQueryConfig,
)


class MergeRequestServiceAsync(MergeRequestService):
    """
    Async Wrapper for MergeRequestServiceAsync
    """

    def create_merge_request(
        self, request_body: MergeRequest = None
    ) -> Awaitable[Union[MergeRequest, str]]:
        return to_async(super().create_merge_request)(request_body)

    def get_merge_request(self, id_: str) -> Awaitable[Union[MergeRequest, str]]:
        return to_async(super().get_merge_request)(id_)

    def update_merge_request(
        self, id_: str, request_body: MergeRequest = None
    ) -> Awaitable[Union[MergeRequest, str]]:
        return to_async(super().update_merge_request)(id_, request_body)

    def delete_merge_request(self, id_: str) -> Awaitable[None]:
        return to_async(super().delete_merge_request)(id_)

    def bulk_merge_request(
        self, request_body: MergeRequestBulkRequest = None
    ) -> Awaitable[Union[MergeRequestBulkResponse, str]]:
        return to_async(super().bulk_merge_request)(request_body)

    def execute_merge_request(
        self, id_: str, request_body: MergeRequest = None
    ) -> Awaitable[Union[MergeRequest, str]]:
        return to_async(super().execute_merge_request)(id_, request_body)

    def query_merge_request(
        self, request_body: MergeRequestQueryConfig = None
    ) -> Awaitable[Union[MergeRequestQueryResponse, str]]:
        return to_async(super().query_merge_request)(request_body)

    def query_more_merge_request(
        self, request_body: str
    ) -> Awaitable[Union[MergeRequestQueryResponse, str]]:
        return to_async(super().query_more_merge_request)(request_body)




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap(
    {
        "environment_id": "environmentId",
        "id_": "id",
        "integration_pack_instance_id": "integrationPackInstanceId",
    }
)
class IntegrationPackEnvironmentAttachment(BaseModel):
    """IntegrationPackEnvironmentAttachment

    :param environment_id: A unique ID assigned by the system to the environment., defaults to None
    :type environment_id: str, optional
    :param id_: The object’s conceptual ID, which is synthesized from the environment and integration pack instance IDs., defaults to None
    :type id_: str, optional
    :param integration_pack_instance_id: A unique ID assigned by the system to the integration pack instance., defaults to None
    :type integration_pack_instance_id: str, optional
    """

    def __init__(
        self,
        environment_id: str = SENTINEL,
        id_: str = SENTINEL,
        integration_pack_instance_id: str = SENTINEL,
        **kwargs
    ):
        """IntegrationPackEnvironmentAttachment

        :param environment_id: A unique ID assigned by the system to the environment., defaults to None
        :type environment_id: str, optional
        :param id_: The object’s conceptual ID, which is synthesized from the environment and integration pack instance IDs., defaults to None
        :type id_: str, optional
        :param integration_pack_instance_id: A unique ID assigned by the system to the integration pack instance., defaults to None
        :type integration_pack_instance_id: str, optional
        """
        if environment_id is not SENTINEL:
            self.environment_id = environment_id
        if id_ is not SENTINEL:
            self.id_ = id_
        if integration_pack_instance_id is not SENTINEL:
            self.integration_pack_instance_id = integration_pack_instance_id
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({})
class TrackedField(BaseModel):
    """TrackedField

    :param name: name, defaults to None
    :type name: str, optional
    :param value: value, defaults to None
    :type value: str, optional
    """

    def __init__(self, name: str = SENTINEL, value: str = SENTINEL, **kwargs):
        """TrackedField

        :param name: name, defaults to None
        :type name: str, optional
        :param value: value, defaults to None
        :type value: str, optional
        """
        if name is not SENTINEL:
            self.name = name
        if value is not SENTINEL:
            self.value = value
        self._kwargs = kwargs




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .deployment_simple_expression import DeploymentSimpleExpression
from .deployment_grouping_expression import DeploymentGroupingExpression


class DeploymentExpressionGuard(OneOfBaseModel):
    class_list = {
        "DeploymentSimpleExpression": DeploymentSimpleExpression,
        "DeploymentGroupingExpression": DeploymentGroupingExpression,
    }


DeploymentExpression = Union[DeploymentSimpleExpression, DeploymentGroupingExpression]





class Request:
    def __init__(self, method, url, headers, body=""):
        self.method = method
        self.url = url
        self.headers = headers
        self.body = body

    def __str__(self):
        return f"method={self.method}, url={self.url}, headers={self.headers}, body={self.body})"


class Response:
    def __init__(self, status, headers, body):
        self.status = status
        self.headers = headers
        self.body = body

    def __str__(self):
        return "Response(status={}, headers={}, body={})".format(
            self.status, self.headers, self.body
        )


class DefaultHook:

    def before_request(self, request: Request, **kwargs):
        pass

    def after_response(self, request: Request, response: Response, **kwargs):
        pass

    def on_error(
        self, error: Exception, request: Request, response: Response, **kwargs
    ):
        pass




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .edifact_connector_record_expression import (
    EdifactConnectorRecordExpression,
    EdifactConnectorRecordExpressionGuard,
)
from .edifact_connector_record_simple_expression import (
    EdifactConnectorRecordSimpleExpression,
)
from .edifact_connector_record_grouping_expression import (
    EdifactConnectorRecordGroupingExpression,
)


@JsonMap({})
class EdifactConnectorRecordQueryConfigQueryFilter(BaseModel):
    """EdifactConnectorRecordQueryConfigQueryFilter

    :param expression: expression
    :type expression: EdifactConnectorRecordExpression
    """

    def __init__(self, expression: EdifactConnectorRecordExpression, **kwargs):
        """EdifactConnectorRecordQueryConfigQueryFilter

        :param expression: expression
        :type expression: EdifactConnectorRecordExpression
        """
        self.expression = EdifactConnectorRecordExpressionGuard.return_one_of(
            expression
        )
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class EdifactConnectorRecordQueryConfig(BaseModel):
    """EdifactConnectorRecordQueryConfig

    :param query_filter: query_filter
    :type query_filter: EdifactConnectorRecordQueryConfigQueryFilter
    """

    def __init__(
        self, query_filter: EdifactConnectorRecordQueryConfigQueryFilter, **kwargs
    ):
        """EdifactConnectorRecordQueryConfig

        :param query_filter: query_filter
        :type query_filter: EdifactConnectorRecordQueryConfigQueryFilter
        """
        self.query_filter = self._define_object(
            query_filter, EdifactConnectorRecordQueryConfigQueryFilter
        )
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap(
    {
        "auth_type": "authType",
        "base_url_for_request": "baseUrlForRequest",
        "default_port": "defaultPort",
        "enable_port": "enablePort",
        "external_port": "externalPort",
        "external_ssl": "externalSSL",
    }
)
class SharedWebServerPort(BaseModel):
    """SharedWebServerPort

    :param auth_type: auth_type
    :type auth_type: str
    :param base_url_for_request: base_url_for_request
    :type base_url_for_request: str
    :param default_port: default_port, defaults to None
    :type default_port: bool, optional
    :param enable_port: enable_port, defaults to None
    :type enable_port: bool, optional
    :param external_port: external_port, defaults to None
    :type external_port: int, optional
    :param external_ssl: external_ssl, defaults to None
    :type external_ssl: bool, optional
    :param port: port, defaults to None
    :type port: int, optional
    :param ssl: ssl, defaults to None
    :type ssl: bool, optional
    """

    def __init__(
        self,
        auth_type: str,
        base_url_for_request: str,
        default_port: bool = SENTINEL,
        enable_port: bool = SENTINEL,
        external_port: int = SENTINEL,
        external_ssl: bool = SENTINEL,
        port: int = SENTINEL,
        ssl: bool = SENTINEL,
        **kwargs
    ):
        """SharedWebServerPort

        :param auth_type: auth_type
        :type auth_type: str
        :param base_url_for_request: base_url_for_request
        :type base_url_for_request: str
        :param default_port: default_port, defaults to None
        :type default_port: bool, optional
        :param enable_port: enable_port, defaults to None
        :type enable_port: bool, optional
        :param external_port: external_port, defaults to None
        :type external_port: int, optional
        :param external_ssl: external_ssl, defaults to None
        :type external_ssl: bool, optional
        :param port: port, defaults to None
        :type port: int, optional
        :param ssl: ssl, defaults to None
        :type ssl: bool, optional
        """
        self.auth_type = auth_type
        self.base_url_for_request = base_url_for_request
        if default_port is not SENTINEL:
            self.default_port = default_port
        if enable_port is not SENTINEL:
            self.enable_port = enable_port
        if external_port is not SENTINEL:
            self.external_port = external_port
        if external_ssl is not SENTINEL:
            self.external_ssl = external_ssl
        if port is not SENTINEL:
            self.port = port
        if ssl is not SENTINEL:
            self.ssl = ssl
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..atom_connector_versions import AtomConnectorVersionsService
from ...models import (
    AtomConnectorVersions,
    AtomConnectorVersionsBulkResponse,
    AtomConnectorVersionsBulkRequest,
)


class AtomConnectorVersionsServiceAsync(AtomConnectorVersionsService):
    """
    Async Wrapper for AtomConnectorVersionsServiceAsync
    """

    def get_atom_connector_versions(
        self, id_: str
    ) -> Awaitable[Union[AtomConnectorVersions, str]]:
        return to_async(super().get_atom_connector_versions)(id_)

    def bulk_atom_connector_versions(
        self, request_body: AtomConnectorVersionsBulkRequest = None
    ) -> Awaitable[Union[AtomConnectorVersionsBulkResponse, str]]:
        return to_async(super().bulk_atom_connector_versions)(request_body)




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .odette_control_info import OdetteControlInfo
from .odette_options import OdetteOptions


@JsonMap(
    {"odette_control_info": "OdetteControlInfo", "odette_options": "OdetteOptions"}
)
class OdettePartnerInfo(BaseModel):
    """OdettePartnerInfo

    :param odette_control_info: odette_control_info
    :type odette_control_info: OdetteControlInfo
    :param odette_options: odette_options
    :type odette_options: OdetteOptions
    """

    def __init__(
        self,
        odette_control_info: OdetteControlInfo,
        odette_options: OdetteOptions,
        **kwargs,
    ):
        """OdettePartnerInfo

        :param odette_control_info: odette_control_info
        :type odette_control_info: OdetteControlInfo
        :param odette_options: odette_options
        :type odette_options: OdetteOptions
        """
        self.odette_control_info = self._define_object(
            odette_control_info, OdetteControlInfo
        )
        self.odette_options = self._define_object(odette_options, OdetteOptions)
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .throughput_account_expression import (
    ThroughputAccountExpression,
    ThroughputAccountExpressionGuard,
)
from .throughput_account_simple_expression import ThroughputAccountSimpleExpression
from .throughput_account_grouping_expression import ThroughputAccountGroupingExpression


@JsonMap({})
class ThroughputAccountQueryConfigQueryFilter(BaseModel):
    """ThroughputAccountQueryConfigQueryFilter

    :param expression: expression
    :type expression: ThroughputAccountExpression
    """

    def __init__(self, expression: ThroughputAccountExpression, **kwargs):
        """ThroughputAccountQueryConfigQueryFilter

        :param expression: expression
        :type expression: ThroughputAccountExpression
        """
        self.expression = ThroughputAccountExpressionGuard.return_one_of(expression)
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class ThroughputAccountQueryConfig(BaseModel):
    """ThroughputAccountQueryConfig

    :param query_filter: query_filter
    :type query_filter: ThroughputAccountQueryConfigQueryFilter
    """

    def __init__(self, query_filter: ThroughputAccountQueryConfigQueryFilter, **kwargs):
        """ThroughputAccountQueryConfig

        :param query_filter: query_filter
        :type query_filter: ThroughputAccountQueryConfigQueryFilter
        """
        self.query_filter = self._define_object(
            query_filter, ThroughputAccountQueryConfigQueryFilter
        )
        self._kwargs = kwargs




from typing import Union
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..net.transport.api_error import ApiError
from ..net.environment.environment import Environment
from ..models.utils.cast_models import cast_models
from ..net.transport.utils import parse_xml_to_dict
from ..models import (
    RuntimeProperties,
    RuntimePropertiesAsyncResponse,
    AsyncOperationTokenResult,
)


class RuntimePropertiesService(BaseService):

    @cast_models
    def update_runtime_properties(
        self, id_: str, request_body: RuntimeProperties = None
    ) -> Union[RuntimeProperties, str]:
        """Updates the RuntimeProperties object having the specified ID.

        :param request_body: The request body., defaults to None
        :type request_body: RuntimeProperties, optional
        :param id_: id_
        :type id_: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[RuntimeProperties, str]
        """

        Validator(RuntimeProperties).is_optional().validate(request_body)
        Validator(str).validate(id_)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/RuntimeProperties/{{id}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("id", id_)
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return RuntimeProperties._unmap(response)
        if content == "application/xml":
            return RuntimeProperties._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def async_get_runtime_properties(
        self, id_: str
    ) -> Union[AsyncOperationTokenResult, str]:
        """Returns a token for the specified RuntimeProperties.

        :param id_: id_
        :type id_: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[AsyncOperationTokenResult, str]
        """

        Validator(str).validate(id_)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/async/RuntimeProperties/{{id}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("id", id_)
            .serialize()
            .set_method("GET")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return AsyncOperationTokenResult._unmap(response)
        if content == "application/xml":
            return AsyncOperationTokenResult._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def async_token_runtime_properties(
        self, token: str
    ) -> Union[RuntimePropertiesAsyncResponse, str]:
        """For a response, use the token from the initial GET response in a new request.

        :param token: Takes in the token from a previous call to return a result.
        :type token: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[RuntimePropertiesAsyncResponse, str]
        """

        Validator(str).validate(token)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/async/RuntimeProperties/response/{{token}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("token", token)
            .serialize()
            .set_method("GET")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return RuntimePropertiesAsyncResponse._unmap(response)
        if content == "application/xml":
            return RuntimePropertiesAsyncResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .topic_subscriber import TopicSubscriber


@JsonMap(
    {
        "dead_letters_count": "deadLettersCount",
        "messages_count": "messagesCount",
        "queue_name": "queueName",
        "queue_type": "queueType",
        "topic_subscribers": "topicSubscribers",
    }
)
class QueueRecord(BaseModel):
    """QueueRecord

    :param dead_letters_count: dead_letters_count, defaults to None
    :type dead_letters_count: int, optional
    :param messages_count: messages_count, defaults to None
    :type messages_count: int, optional
    :param queue_name: queue_name, defaults to None
    :type queue_name: str, optional
    :param queue_type: queue_type, defaults to None
    :type queue_type: str, optional
    :param topic_subscribers: topic_subscribers, defaults to None
    :type topic_subscribers: List[TopicSubscriber], optional
    """

    def __init__(
        self,
        dead_letters_count: int = SENTINEL,
        messages_count: int = SENTINEL,
        queue_name: str = SENTINEL,
        queue_type: str = SENTINEL,
        topic_subscribers: List[TopicSubscriber] = SENTINEL,
        **kwargs,
    ):
        """QueueRecord

        :param dead_letters_count: dead_letters_count, defaults to None
        :type dead_letters_count: int, optional
        :param messages_count: messages_count, defaults to None
        :type messages_count: int, optional
        :param queue_name: queue_name, defaults to None
        :type queue_name: str, optional
        :param queue_type: queue_type, defaults to None
        :type queue_type: str, optional
        :param topic_subscribers: topic_subscribers, defaults to None
        :type topic_subscribers: List[TopicSubscriber], optional
        """
        if dead_letters_count is not SENTINEL:
            self.dead_letters_count = dead_letters_count
        if messages_count is not SENTINEL:
            self.messages_count = messages_count
        if queue_name is not SENTINEL:
            self.queue_name = queue_name
        if queue_type is not SENTINEL:
            self.queue_type = queue_type
        if topic_subscribers is not SENTINEL:
            self.topic_subscribers = self._define_list(
                topic_subscribers, TopicSubscriber
            )
        self._kwargs = kwargs




from typing import Union
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..net.transport.api_error import ApiError
from ..net.environment.environment import Environment
from ..models.utils.cast_models import cast_models
from ..net.transport.utils import parse_xml_to_dict
from ..models import ExecutionArtifacts, LogDownload


class ExecutionArtifactsService(BaseService):

    @cast_models
    def create_execution_artifacts(
        self, request_body: ExecutionArtifacts = None
    ) -> Union[LogDownload, str]:
        """Allows you to retrieve a link for downloading detailed information about a given process run.
         - You must have the Runtime Management privilege to perform the CREATE operation. If you have the Runtime Management Read Access privilege, you cannot download execution artifacts.
         - Additionally, as the Cloud owner, you must select the **Enable Download of Execution Artifacts and Worker Logs** property for your account. This property permits you to download process execution data, and you can access it from the Cloud Attachment Quota tab of Manage > Cloud Management.
         - After providing the endpoint and a request body containing the execution ID, the CREATE response returns a download URL that you can open (or copy and paste) in your web browser, which initiates the file download to your local drive.
         To retrieve the download link for file containing a process execution artifacts,
         1. First create a CREATE (or POST) request to `https://api.boomi.com/api/rest/v1/<accountId>/ExecutionArtifacts` where `accountId` is the ID of the account authenticating the request.
         2. Populate the request body with the `executionId`, which is the identifier of the given run process.
         3. Send the request and either open or copy and paste the URL from the response into your web browser.

        :param request_body: The request body., defaults to None
        :type request_body: ExecutionArtifacts, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[LogDownload, str]
        """

        Validator(ExecutionArtifacts).is_optional().validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/ExecutionArtifacts",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return LogDownload._unmap(response)
        if content == "application/xml":
            return LogDownload._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    def download_execution_artifacts(
        self,
        request_body: ExecutionArtifacts = None,
        max_retries: int = 10,
        initial_delay: float = 2.0,
    ) -> bytes:
        """Request and download execution artifacts.

        Combines the two-phase download process: submits the download request via
        create_execution_artifacts(), then polls the returned URL until the content is ready.

        :param request_body: The request body., defaults to None
        :type request_body: ExecutionArtifacts, optional
        :param max_retries: Maximum number of polling attempts., defaults to 10
        :type max_retries: int
        :param initial_delay: Initial delay in seconds between retries., defaults to 2.0
        :type initial_delay: float
        :return: The raw artifact content as bytes (typically a ZIP file).
        :rtype: bytes
        """
        result = self.create_execution_artifacts(request_body=request_body)
        if hasattr(result, "status_code") and str(result.status_code) == "504":
            raise ApiError("Runtime unavailable for artifact download", 504, result)
        if not hasattr(result, "url") or not result.url:
            raise ApiError("No download URL in response", 0, result)
        return self._poll_download_url(
            result.url, max_retries=max_retries, initial_delay=initial_delay
        )




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .event_simple_expression import EventSimpleExpression
from .event_grouping_expression import EventGroupingExpression


class EventExpressionGuard(OneOfBaseModel):
    class_list = {
        "EventSimpleExpression": EventSimpleExpression,
        "EventGroupingExpression": EventGroupingExpression,
    }


EventExpression = Union[EventSimpleExpression, EventGroupingExpression]




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .edifact_control_info import EdifactControlInfo
from .edifact_options import EdifactOptions


@JsonMap(
    {"edifact_control_info": "EdifactControlInfo", "edifact_options": "EdifactOptions"}
)
class EdifactPartnerInfo(BaseModel):
    """EdifactPartnerInfo

    :param edifact_control_info: edifact_control_info
    :type edifact_control_info: EdifactControlInfo
    :param edifact_options: edifact_options
    :type edifact_options: EdifactOptions
    """

    def __init__(
        self,
        edifact_control_info: EdifactControlInfo = SENTINEL,
        edifact_options: EdifactOptions = SENTINEL,
        **kwargs,
    ):
        """EdifactPartnerInfo

        :param edifact_control_info: edifact_control_info, defaults to None
        :type edifact_control_info: EdifactControlInfo, optional
        :param edifact_options: edifact_options, defaults to None
        :type edifact_options: EdifactOptions, optional
        """
        if edifact_control_info is not SENTINEL:
            self.edifact_control_info = self._define_object(
                edifact_control_info, EdifactControlInfo
            )
        if edifact_options is not SENTINEL:
            self.edifact_options = self._define_object(edifact_options, EdifactOptions)
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .custom_fields import CustomFields


@JsonMap(
    {
        "accept_ack_report": "acceptAckReport",
        "accept_ack_status": "acceptAckStatus",
        "ack_report": "ackReport",
        "ack_status": "ackStatus",
        "action_type": "actionType",
        "atom_id": "atomId",
        "connector_name": "connectorName",
        "connector_type": "connectorType",
        "custom_fields": "customFields",
        "date_processed": "dateProcessed",
        "document_index": "documentIndex",
        "error_message": "errorMessage",
        "execution_id": "executionId",
        "id_": "id",
        "is_valid_message": "isValidMessage",
        "message_control_id": "messageControlId",
        "message_type": "messageType",
        "operation_name": "operationName",
        "outbound_validation_report": "outboundValidationReport",
        "outbound_validation_status": "outboundValidationStatus",
        "receiver_application_id": "receiverApplicationId",
        "receiver_facility_id": "receiverFacilityId",
        "sender_application_id": "senderApplicationId",
        "sender_facility_id": "senderFacilityId",
    }
)
class Hl7ConnectorRecord(BaseModel):
    """Hl7ConnectorRecord

    :param accept_ack_report: The Accept Acknowledgment Report., defaults to None
    :type accept_ack_report: str, optional
    :param accept_ack_status: The Accept Acknowledgment status — either *Commit Accept*, *Commit Error*, or *Commit Reject*., defaults to None
    :type accept_ack_status: str, optional
    :param account: The ID of the account in which you ran this record.
    :type account: str
    :param ack_report: The acknowledgment report., defaults to None
    :type ack_report: str, optional
    :param ack_status: The acknowledgment status — either *Application Accept*, *Application Error*, or *Application Reject*., defaults to None
    :type ack_status: str, optional
    :param action_type: The type of action with which this record corresponds — *Send* for an outbound interchange or *Listen* for an inbound interchange.
    :type action_type: str
    :param atom_id: The processing ID of the Runtime for this record.
    :type atom_id: str
    :param connector_name: The value is *Trading Partner* for an HL7 trading partner Send operation, or *Start* for an HL7 trading partner Listen operation.
    :type connector_name: str
    :param connector_type: *hl7* is the connector type for any record.
    :type connector_type: str
    :param custom_fields: custom_fields
    :type custom_fields: CustomFields
    :param date_processed: The processing date and time of this record. The format is yyyy-MM-dd'T'HH:mm:ss'Z', for example 2019-09-14T15:32:00Z.
    :type date_processed: str
    :param document_index: The numerical index of this record in the run., defaults to None
    :type document_index: int, optional
    :param error_message: Any error message associated with this record. This field is omitted for a successful interchange.
    :type error_message: str
    :param execution_id: The ID of the run.
    :type execution_id: str
    :param id_: The ID of this record.
    :type id_: str
    :param is_valid_message: If the message satisfies the requirements of the referenced profile’s segment and element configuration, including mandatory fields, data types, and minimum and maximum lengths, the value is true. Otherwise, the value is false., defaults to None
    :type is_valid_message: str, optional
    :param message_control_id: The unique identifier for the message., defaults to None
    :type message_control_id: str, optional
    :param message_type: The code identifying the type of message., defaults to None
    :type message_type: str, optional
    :param operation_name: The name of the operation component processing the record.
    :type operation_name: str
    :param outbound_validation_report: The outbound validation report. This report contains descriptions of errors present in the outbound interchange. If the outbound validation option is not selected in the sending trading partner, the value is N/A. The API omits this field or an inbound interchange., defaults to None
    :type outbound_validation_report: str, optional
    :param outbound_validation_status: The outbound validation status — is either Success, Error-Interchange, Error-Message, or N/A. For an outbound interchange for which you do not select the outbound validation option in the sending trading partner, the value is N/A. This field is omitted for an inbound interchange., defaults to None
    :type outbound_validation_status: str, optional
    :param receiver_application_id: The ID of the receiving application among all other applications within the network enterprise., defaults to None
    :type receiver_application_id: str, optional
    :param receiver_facility_id: Additional detail regarding the receiving application., defaults to None
    :type receiver_facility_id: str, optional
    :param sender_application_id: The ID of the sending application among all other applications within the network enterprise., defaults to None
    :type sender_application_id: str, optional
    :param sender_facility_id: Additional detail regarding the sending application., defaults to None
    :type sender_facility_id: str, optional
    :param size: The size, in bytes, of the document that corresponds to this record., defaults to None
    :type size: int, optional
    :param successful: Whether the record is a success or error., defaults to None
    :type successful: bool, optional
    :param version: The applicable HL7 version., defaults to None
    :type version: str, optional
    """

    def __init__(
        self,
        account: str,
        action_type: str,
        atom_id: str,
        connector_name: str,
        connector_type: str,
        custom_fields: CustomFields,
        date_processed: str,
        error_message: str,
        execution_id: str,
        id_: str,
        operation_name: str,
        accept_ack_report: str = SENTINEL,
        accept_ack_status: str = SENTINEL,
        ack_report: str = SENTINEL,
        ack_status: str = SENTINEL,
        document_index: int = SENTINEL,
        is_valid_message: str = SENTINEL,
        message_control_id: str = SENTINEL,
        message_type: str = SENTINEL,
        outbound_validation_report: str = SENTINEL,
        outbound_validation_status: str = SENTINEL,
        receiver_application_id: str = SENTINEL,
        receiver_facility_id: str = SENTINEL,
        sender_application_id: str = SENTINEL,
        sender_facility_id: str = SENTINEL,
        size: int = SENTINEL,
        successful: bool = SENTINEL,
        version: str = SENTINEL,
        **kwargs,
    ):
        """Hl7ConnectorRecord

        :param accept_ack_report: The Accept Acknowledgment Report., defaults to None
        :type accept_ack_report: str, optional
        :param accept_ack_status: The Accept Acknowledgment status — either *Commit Accept*, *Commit Error*, or *Commit Reject*., defaults to None
        :type accept_ack_status: str, optional
        :param account: The ID of the account in which you ran this record.
        :type account: str
        :param ack_report: The acknowledgment report., defaults to None
        :type ack_report: str, optional
        :param ack_status: The acknowledgment status — either *Application Accept*, *Application Error*, or *Application Reject*., defaults to None
        :type ack_status: str, optional
        :param action_type: The type of action with which this record corresponds — *Send* for an outbound interchange or *Listen* for an inbound interchange.
        :type action_type: str
        :param atom_id: The processing ID of the Runtime for this record.
        :type atom_id: str
        :param connector_name: The value is *Trading Partner* for an HL7 trading partner Send operation, or *Start* for an HL7 trading partner Listen operation.
        :type connector_name: str
        :param connector_type: *hl7* is the connector type for any record.
        :type connector_type: str
        :param custom_fields: custom_fields
        :type custom_fields: CustomFields
        :param date_processed: The processing date and time of this record. The format is yyyy-MM-dd'T'HH:mm:ss'Z', for example 2019-09-14T15:32:00Z.
        :type date_processed: str
        :param document_index: The numerical index of this record in the run., defaults to None
        :type document_index: int, optional
        :param error_message: Any error message associated with this record. This field is omitted for a successful interchange.
        :type error_message: str
        :param execution_id: The ID of the run.
        :type execution_id: str
        :param id_: The ID of this record.
        :type id_: str
        :param is_valid_message: If the message satisfies the requirements of the referenced profile’s segment and element configuration, including mandatory fields, data types, and minimum and maximum lengths, the value is true. Otherwise, the value is false., defaults to None
        :type is_valid_message: str, optional
        :param message_control_id: The unique identifier for the message., defaults to None
        :type message_control_id: str, optional
        :param message_type: The code identifying the type of message., defaults to None
        :type message_type: str, optional
        :param operation_name: The name of the operation component processing the record.
        :type operation_name: str
        :param outbound_validation_report: The outbound validation report. This report contains descriptions of errors present in the outbound interchange. If the outbound validation option is not selected in the sending trading partner, the value is N/A. The API omits this field or an inbound interchange., defaults to None
        :type outbound_validation_report: str, optional
        :param outbound_validation_status: The outbound validation status — is either Success, Error-Interchange, Error-Message, or N/A. For an outbound interchange for which you do not select the outbound validation option in the sending trading partner, the value is N/A. This field is omitted for an inbound interchange., defaults to None
        :type outbound_validation_status: str, optional
        :param receiver_application_id: The ID of the receiving application among all other applications within the network enterprise., defaults to None
        :type receiver_application_id: str, optional
        :param receiver_facility_id: Additional detail regarding the receiving application., defaults to None
        :type receiver_facility_id: str, optional
        :param sender_application_id: The ID of the sending application among all other applications within the network enterprise., defaults to None
        :type sender_application_id: str, optional
        :param sender_facility_id: Additional detail regarding the sending application., defaults to None
        :type sender_facility_id: str, optional
        :param size: The size, in bytes, of the document that corresponds to this record., defaults to None
        :type size: int, optional
        :param successful: Whether the record is a success or error., defaults to None
        :type successful: bool, optional
        :param version: The applicable HL7 version., defaults to None
        :type version: str, optional
        """
        if accept_ack_report is not SENTINEL:
            self.accept_ack_report = accept_ack_report
        if accept_ack_status is not SENTINEL:
            self.accept_ack_status = accept_ack_status
        self.account = account
        if ack_report is not SENTINEL:
            self.ack_report = ack_report
        if ack_status is not SENTINEL:
            self.ack_status = ack_status
        self.action_type = action_type
        self.atom_id = atom_id
        self.connector_name = connector_name
        self.connector_type = connector_type
        self.custom_fields = self._define_object(custom_fields, CustomFields)
        self.date_processed = date_processed
        if document_index is not SENTINEL:
            self.document_index = document_index
        self.error_message = error_message
        self.execution_id = execution_id
        self.id_ = id_
        if is_valid_message is not SENTINEL:
            self.is_valid_message = is_valid_message
        if message_control_id is not SENTINEL:
            self.message_control_id = message_control_id
        if message_type is not SENTINEL:
            self.message_type = message_type
        self.operation_name = operation_name
        if outbound_validation_report is not SENTINEL:
            self.outbound_validation_report = outbound_validation_report
        if outbound_validation_status is not SENTINEL:
            self.outbound_validation_status = outbound_validation_status
        if receiver_application_id is not SENTINEL:
            self.receiver_application_id = receiver_application_id
        if receiver_facility_id is not SENTINEL:
            self.receiver_facility_id = receiver_facility_id
        if sender_application_id is not SENTINEL:
            self.sender_application_id = sender_application_id
        if sender_facility_id is not SENTINEL:
            self.sender_facility_id = sender_facility_id
        if size is not SENTINEL:
            self.size = size
        if successful is not SENTINEL:
            self.successful = successful
        if version is not SENTINEL:
            self.version = version
        self._kwargs = kwargs




from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({})
class CustomFields(BaseModel):
    """CustomFields

    :param fields: fields, defaults to None
    :type fields: List[dict], optional
    """

    def __init__(self, fields: List[dict] = SENTINEL, **kwargs):
        """CustomFields

        :param fields: fields, defaults to None
        :type fields: List[dict], optional
        """
        if fields is not SENTINEL:
            self.fields = fields
        self._kwargs = kwargs




from __future__ import annotations
from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .resources import Resources


class AutoSubscribeAlertLevel(Enum):
    """An enumeration representing different categories.

    :cvar NONE: "none"
    :vartype NONE: str
    :cvar INFO: "info"
    :vartype INFO: str
    :cvar WARNING: "warning"
    :vartype WARNING: str
    :cvar ERROR: "error"
    :vartype ERROR: str
    """

    NONE = "none"
    INFO = "info"
    WARNING = "warning"
    ERROR = "error"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, AutoSubscribeAlertLevel._member_map_.values())
        )


@JsonMap(
    {
        "resources": "Resources",
        "account_id": "accountId",
        "auto_subscribe_alert_level": "autoSubscribeAlertLevel",
        "default_group": "defaultGroup",
        "id_": "id",
    }
)
class AccountGroup(BaseModel):
    """AccountGroup

    :param resources: resources, defaults to None
    :type resources: Resources, optional
    :param account_id: The ID of the primary account under which the account group exists., defaults to None
    :type account_id: str, optional
    :param auto_subscribe_alert_level: The severity level of email alerts sent to member users in the account group., defaults to None
    :type auto_subscribe_alert_level: AutoSubscribeAlertLevel, optional
    :param default_group: true — The account group is All Accounts, which the system creates automatically.\<br /\> false — The account group is not All Accounts., defaults to None
    :type default_group: bool, optional
    :param id_: The ID of the account group., defaults to None
    :type id_: str, optional
    :param name: The name of the account group as displayed on the **Account Information** tab of the **Setup** page., defaults to None
    :type name: str, optional
    """

    def __init__(
        self,
        resources: Resources = SENTINEL,
        account_id: str = SENTINEL,
        auto_subscribe_alert_level: AutoSubscribeAlertLevel = SENTINEL,
        default_group: bool = SENTINEL,
        id_: str = SENTINEL,
        name: str = SENTINEL,
        **kwargs,
    ):
        """AccountGroup

        :param resources: resources, defaults to None
        :type resources: Resources, optional
        :param account_id: The ID of the primary account under which the account group exists., defaults to None
        :type account_id: str, optional
        :param auto_subscribe_alert_level: The severity level of email alerts sent to member users in the account group., defaults to None
        :type auto_subscribe_alert_level: AutoSubscribeAlertLevel, optional
        :param default_group: true — The account group is All Accounts, which the system creates automatically.\<br /\> false — The account group is not All Accounts., defaults to None
        :type default_group: bool, optional
        :param id_: The ID of the account group., defaults to None
        :type id_: str, optional
        :param name: The name of the account group as displayed on the **Account Information** tab of the **Setup** page., defaults to None
        :type name: str, optional
        """
        if resources is not SENTINEL:
            self.resources = self._define_object(resources, Resources)
        if account_id is not SENTINEL:
            self.account_id = account_id
        if auto_subscribe_alert_level is not SENTINEL:
            self.auto_subscribe_alert_level = self._enum_matching(
                auto_subscribe_alert_level,
                AutoSubscribeAlertLevel.list(),
                "auto_subscribe_alert_level",
            )
        if default_group is not SENTINEL:
            self.default_group = default_group
        if id_ is not SENTINEL:
            self.id_ = id_
        if name is not SENTINEL:
            self.name = name
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..process_environment_attachment import ProcessEnvironmentAttachmentService
from ...models import ProcessEnvironmentAttachment


class ProcessEnvironmentAttachmentServiceAsync(ProcessEnvironmentAttachmentService):
    """
    Async Wrapper for ProcessEnvironmentAttachmentServiceAsync
    """

    def create_process_environment_attachment(
        self, request_body: ProcessEnvironmentAttachment = None
    ) -> Awaitable[Union[ProcessEnvironmentAttachment, str]]:
        return to_async(super().create_process_environment_attachment)(request_body)




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .scripting_parameter import ScriptingParameter


@JsonMap({"output": "Output"})
class ScriptingOutputs(BaseModel):
    """ScriptingOutputs

    :param output: output, defaults to None
    :type output: List[ScriptingParameter], optional
    """

    def __init__(self, output: List[ScriptingParameter] = SENTINEL, **kwargs):
        """ScriptingOutputs

        :param output: output, defaults to None
        :type output: List[ScriptingParameter], optional
        """
        if output is not SENTINEL:
            self.output = self._define_list(output, ScriptingParameter)
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..generic_connector_record import GenericConnectorRecordService
from ...models import (
    GenericConnectorRecord,
    GenericConnectorRecordBulkResponse,
    GenericConnectorRecordBulkRequest,
    GenericConnectorRecordQueryResponse,
    GenericConnectorRecordQueryConfig,
)


class GenericConnectorRecordServiceAsync(GenericConnectorRecordService):
    """
    Async Wrapper for GenericConnectorRecordServiceAsync
    """

    def get_generic_connector_record(
        self, id_: str
    ) -> Awaitable[Union[GenericConnectorRecord, str]]:
        return to_async(super().get_generic_connector_record)(id_)

    def bulk_generic_connector_record(
        self, request_body: GenericConnectorRecordBulkRequest = None
    ) -> Awaitable[Union[GenericConnectorRecordBulkResponse, str]]:
        return to_async(super().bulk_generic_connector_record)(request_body)

    def query_generic_connector_record(
        self, request_body: GenericConnectorRecordQueryConfig = None
    ) -> Awaitable[Union[GenericConnectorRecordQueryResponse, str]]:
        return to_async(super().query_generic_connector_record)(request_body)

    def query_more_generic_connector_record(
        self, request_body: str
    ) -> Awaitable[Union[GenericConnectorRecordQueryResponse, str]]:
        return to_async(super().query_more_generic_connector_record)(request_body)




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap(
    {
        "client_ssl_alias": "clientSSLAlias",
        "encrypting_certificate": "encrypting-certificate",
        "session_challenge_certificate": "session-challenge-certificate",
        "sfidsec_encrypt": "sfidsec-encrypt",
        "sfidsec_sign": "sfidsec-sign",
        "verifying_eerp_certificate": "verifying-eerp-certificate",
        "verifying_signature_certificate": "verifying-signature-certificate",
    }
)
class OftpPartnerInfo(BaseModel):
    """OftpPartnerInfo

    :param client_ssl_alias: client_ssl_alias, defaults to None
    :type client_ssl_alias: str, optional
    :param encrypting_certificate: encrypting_certificate, defaults to None
    :type encrypting_certificate: str, optional
    :param session_challenge_certificate: session_challenge_certificate, defaults to None
    :type session_challenge_certificate: str, optional
    :param sfidsec_encrypt: sfidsec_encrypt, defaults to None
    :type sfidsec_encrypt: bool, optional
    :param sfidsec_sign: sfidsec_sign, defaults to None
    :type sfidsec_sign: bool, optional
    :param sfidsign: sfidsign, defaults to None
    :type sfidsign: bool, optional
    :param ssidcmpr: ssidcmpr, defaults to None
    :type ssidcmpr: bool, optional
    :param ssidcode: ssidcode, defaults to None
    :type ssidcode: str, optional
    :param ssidpswd: ssidpswd, defaults to None
    :type ssidpswd: str, optional
    :param verifying_eerp_certificate: verifying_eerp_certificate, defaults to None
    :type verifying_eerp_certificate: str, optional
    :param verifying_signature_certificate: verifying_signature_certificate, defaults to None
    :type verifying_signature_certificate: str, optional
    """

    def __init__(
        self,
        client_ssl_alias: str = SENTINEL,
        encrypting_certificate: str = SENTINEL,
        session_challenge_certificate: str = SENTINEL,
        sfidsec_encrypt: bool = SENTINEL,
        sfidsec_sign: bool = SENTINEL,
        sfidsign: bool = SENTINEL,
        ssidcmpr: bool = SENTINEL,
        ssidcode: str = SENTINEL,
        ssidpswd: str = SENTINEL,
        verifying_eerp_certificate: str = SENTINEL,
        verifying_signature_certificate: str = SENTINEL,
        **kwargs
    ):
        """OftpPartnerInfo

        :param client_ssl_alias: client_ssl_alias, defaults to None
        :type client_ssl_alias: str, optional
        :param encrypting_certificate: encrypting_certificate, defaults to None
        :type encrypting_certificate: str, optional
        :param session_challenge_certificate: session_challenge_certificate, defaults to None
        :type session_challenge_certificate: str, optional
        :param sfidsec_encrypt: sfidsec_encrypt, defaults to None
        :type sfidsec_encrypt: bool, optional
        :param sfidsec_sign: sfidsec_sign, defaults to None
        :type sfidsec_sign: bool, optional
        :param sfidsign: sfidsign, defaults to None
        :type sfidsign: bool, optional
        :param ssidcmpr: ssidcmpr, defaults to None
        :type ssidcmpr: bool, optional
        :param ssidcode: ssidcode, defaults to None
        :type ssidcode: str, optional
        :param ssidpswd: ssidpswd, defaults to None
        :type ssidpswd: str, optional
        :param verifying_eerp_certificate: verifying_eerp_certificate, defaults to None
        :type verifying_eerp_certificate: str, optional
        :param verifying_signature_certificate: verifying_signature_certificate, defaults to None
        :type verifying_signature_certificate: str, optional
        """
        if client_ssl_alias is not SENTINEL:
            self.client_ssl_alias = client_ssl_alias
        if encrypting_certificate is not SENTINEL:
            self.encrypting_certificate = encrypting_certificate
        if session_challenge_certificate is not SENTINEL:
            self.session_challenge_certificate = session_challenge_certificate
        if sfidsec_encrypt is not SENTINEL:
            self.sfidsec_encrypt = sfidsec_encrypt
        if sfidsec_sign is not SENTINEL:
            self.sfidsec_sign = sfidsec_sign
        if sfidsign is not SENTINEL:
            self.sfidsign = sfidsign
        if ssidcmpr is not SENTINEL:
            self.ssidcmpr = ssidcmpr
        if ssidcode is not SENTINEL:
            self.ssidcode = ssidcode
        if ssidpswd is not SENTINEL:
            self.ssidpswd = ssidpswd
        if verifying_eerp_certificate is not SENTINEL:
            self.verifying_eerp_certificate = verifying_eerp_certificate
        if verifying_signature_certificate is not SENTINEL:
            self.verifying_signature_certificate = verifying_signature_certificate
        self._kwargs = kwargs




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .edi_custom_connector_record_simple_expression import (
    EdiCustomConnectorRecordSimpleExpression,
)
from .edi_custom_connector_record_grouping_expression import (
    EdiCustomConnectorRecordGroupingExpression,
)


class EdiCustomConnectorRecordExpressionGuard(OneOfBaseModel):
    class_list = {
        "EdiCustomConnectorRecordSimpleExpression": EdiCustomConnectorRecordSimpleExpression,
        "EdiCustomConnectorRecordGroupingExpression": EdiCustomConnectorRecordGroupingExpression,
    }


EdiCustomConnectorRecordExpression = Union[
    EdiCustomConnectorRecordSimpleExpression, EdiCustomConnectorRecordGroupingExpression
]




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..component import ComponentService
from ...models import Component, ComponentBulkResponse, ComponentBulkRequest


class ComponentServiceAsync(ComponentService):
    """
    Async Wrapper for ComponentServiceAsync
    """

    def create_component(
        self, request_body: str = None
    ) -> Awaitable[Union[Component, str]]:
        return to_async(super().create_component)(request_body)

    def get_component(self, component_id: str) -> Awaitable[Union[Component, str]]:
        return to_async(super().get_component)(component_id)

    def update_component(
        self, component_id: str, request_body: str = None
    ) -> Awaitable[Union[Component, str]]:
        return to_async(super().update_component)(component_id, request_body)

    def bulk_component(
        self, request_body: ComponentBulkRequest = None
    ) -> Awaitable[str]:
        return to_async(super().bulk_component)(request_body)




from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class DeployedPackageSimpleExpressionOperator(Enum):
    """An enumeration representing different categories.

    :cvar EQUALS: "EQUALS"
    :vartype EQUALS: str
    :cvar LIKE: "LIKE"
    :vartype LIKE: str
    :cvar NOTEQUALS: "NOT_EQUALS"
    :vartype NOTEQUALS: str
    :cvar ISNULL: "IS_NULL"
    :vartype ISNULL: str
    :cvar ISNOTNULL: "IS_NOT_NULL"
    :vartype ISNOTNULL: str
    :cvar BETWEEN: "BETWEEN"
    :vartype BETWEEN: str
    :cvar GREATERTHAN: "GREATER_THAN"
    :vartype GREATERTHAN: str
    :cvar GREATERTHANOREQUAL: "GREATER_THAN_OR_EQUAL"
    :vartype GREATERTHANOREQUAL: str
    :cvar LESSTHAN: "LESS_THAN"
    :vartype LESSTHAN: str
    :cvar LESSTHANOREQUAL: "LESS_THAN_OR_EQUAL"
    :vartype LESSTHANOREQUAL: str
    :cvar CONTAINS: "CONTAINS"
    :vartype CONTAINS: str
    :cvar NOTCONTAINS: "NOT_CONTAINS"
    :vartype NOTCONTAINS: str
    """

    EQUALS = "EQUALS"
    LIKE = "LIKE"
    NOTEQUALS = "NOT_EQUALS"
    ISNULL = "IS_NULL"
    ISNOTNULL = "IS_NOT_NULL"
    BETWEEN = "BETWEEN"
    GREATERTHAN = "GREATER_THAN"
    GREATERTHANOREQUAL = "GREATER_THAN_OR_EQUAL"
    LESSTHAN = "LESS_THAN"
    LESSTHANOREQUAL = "LESS_THAN_OR_EQUAL"
    CONTAINS = "CONTAINS"
    NOTCONTAINS = "NOT_CONTAINS"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                DeployedPackageSimpleExpressionOperator._member_map_.values(),
            )
        )


class DeployedPackageSimpleExpressionProperty(Enum):
    """An enumeration representing different categories.

    :cvar UID: "uid"
    :vartype UID: str
    :cvar NOTES: "notes"
    :vartype NOTES: str
    :cvar CURRENT: "current"
    :vartype CURRENT: str
    :cvar PACKAGENOTES: "packageNotes"
    :vartype PACKAGENOTES: str
    :cvar ACTIVE: "active"
    :vartype ACTIVE: str
    :cvar COMPONENTID: "componentId"
    :vartype COMPONENTID: str
    :cvar COMPONENTVERSION: "componentVersion"
    :vartype COMPONENTVERSION: str
    :cvar COMPONENTNAME: "componentName"
    :vartype COMPONENTNAME: str
    :cvar COMPONENTTYPE: "componentType"
    :vartype COMPONENTTYPE: str
    :cvar DEPLOYEDBY: "deployedBy"
    :vartype DEPLOYEDBY: str
    :cvar DEPLOYEDDATE: "deployedDate"
    :vartype DEPLOYEDDATE: str
    :cvar DEPLOYMENTID: "deploymentId"
    :vartype DEPLOYMENTID: str
    :cvar ENVIRONMENTID: "environmentId"
    :vartype ENVIRONMENTID: str
    :cvar ENVIRONMENTNAME: "environmentName"
    :vartype ENVIRONMENTNAME: str
    :cvar PACKAGEID: "packageId"
    :vartype PACKAGEID: str
    :cvar PACKAGEVERSION: "packageVersion"
    :vartype PACKAGEVERSION: str
    :cvar VERSION: "version"
    :vartype VERSION: str
    :cvar ACCOUNTID: "accountId"
    :vartype ACCOUNTID: str
    :cvar BRANCH: "branch"
    :vartype BRANCH: str
    """

    UID = "uid"
    NOTES = "notes"
    CURRENT = "current"
    PACKAGENOTES = "packageNotes"
    ACTIVE = "active"
    COMPONENTID = "componentId"
    COMPONENTVERSION = "componentVersion"
    COMPONENTNAME = "componentName"
    COMPONENTTYPE = "componentType"
    DEPLOYEDBY = "deployedBy"
    DEPLOYEDDATE = "deployedDate"
    DEPLOYMENTID = "deploymentId"
    ENVIRONMENTID = "environmentId"
    ENVIRONMENTNAME = "environmentName"
    PACKAGEID = "packageId"
    PACKAGEVERSION = "packageVersion"
    VERSION = "version"
    ACCOUNTID = "accountId"
    BRANCH = "branch"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                DeployedPackageSimpleExpressionProperty._member_map_.values(),
            )
        )


@JsonMap({})
class DeployedPackageSimpleExpression(BaseModel):
    """DeployedPackageSimpleExpression

    :param argument: argument, defaults to None
    :type argument: List[str], optional
    :param operator: operator
    :type operator: DeployedPackageSimpleExpressionOperator
    :param property: property
    :type property: DeployedPackageSimpleExpressionProperty
    """

    def __init__(
        self,
        operator: DeployedPackageSimpleExpressionOperator,
        property: DeployedPackageSimpleExpressionProperty,
        argument: List[str] = SENTINEL,
        **kwargs
    ):
        """DeployedPackageSimpleExpression

        :param argument: argument, defaults to None
        :type argument: List[str], optional
        :param operator: operator
        :type operator: DeployedPackageSimpleExpressionOperator
        :param property: property
        :type property: DeployedPackageSimpleExpressionProperty
        """
        if argument is not SENTINEL:
            self.argument = argument
        self.operator = self._enum_matching(
            operator, DeployedPackageSimpleExpressionOperator.list(), "operator"
        )
        self.property = self._enum_matching(
            property, DeployedPackageSimpleExpressionProperty.list(), "property"
        )
        self._kwargs = kwargs




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .document_count_account_group_simple_expression import (
    DocumentCountAccountGroupSimpleExpression,
)
from .document_count_account_group_grouping_expression import (
    DocumentCountAccountGroupGroupingExpression,
)


class DocumentCountAccountGroupExpressionGuard(OneOfBaseModel):
    class_list = {
        "DocumentCountAccountGroupSimpleExpression": DocumentCountAccountGroupSimpleExpression,
        "DocumentCountAccountGroupGroupingExpression": DocumentCountAccountGroupGroupingExpression,
    }


DocumentCountAccountGroupExpression = Union[
    DocumentCountAccountGroupSimpleExpression,
    DocumentCountAccountGroupGroupingExpression,
]




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .shared_web_server_authentication import SharedWebServerAuthentication
from .listener_port_configuration import ListenerPortConfiguration
from .shared_web_server_protected_headers import SharedWebServerProtectedHeaders


@JsonMap(
    {
        "api_type": "apiType",
        "base_url": "baseUrl",
        "examine_forward_headers": "examineForwardHeaders",
        "external_host": "externalHost",
        "internal_host": "internalHost",
        "listener_ports": "listenerPorts",
        "max_number_of_threads": "maxNumberOfThreads",
        "override_url": "overrideUrl",
        "protected_headers": "protectedHeaders",
        "ssl_certificate": "sslCertificate",
    }
)
class SharedWebServerGeneral(BaseModel):
    """SharedWebServerGeneral

    :param api_type: api_type
    :type api_type: str
    :param authentication: authentication
    :type authentication: SharedWebServerAuthentication
    :param base_url: base_url
    :type base_url: str
    :param examine_forward_headers: examine_forward_headers, defaults to None
    :type examine_forward_headers: bool, optional
    :param external_host: external_host
    :type external_host: str
    :param internal_host: internal_host
    :type internal_host: str
    :param listener_ports: listener_ports
    :type listener_ports: ListenerPortConfiguration
    :param max_number_of_threads: max_number_of_threads, defaults to None
    :type max_number_of_threads: int, optional
    :param override_url: override_url, defaults to None
    :type override_url: bool, optional
    :param protected_headers: protected_headers
    :type protected_headers: SharedWebServerProtectedHeaders
    :param ssl_certificate: ssl_certificate
    :type ssl_certificate: str
    """

    def __init__(
        self,
        api_type: str,
        authentication: SharedWebServerAuthentication,
        base_url: str,
        external_host: str,
        internal_host: str,
        listener_ports: ListenerPortConfiguration,
        protected_headers: SharedWebServerProtectedHeaders,
        ssl_certificate: str,
        examine_forward_headers: bool = SENTINEL,
        max_number_of_threads: int = SENTINEL,
        override_url: bool = SENTINEL,
        **kwargs,
    ):
        """SharedWebServerGeneral

        :param api_type: api_type
        :type api_type: str
        :param authentication: authentication
        :type authentication: SharedWebServerAuthentication
        :param base_url: base_url
        :type base_url: str
        :param examine_forward_headers: examine_forward_headers, defaults to None
        :type examine_forward_headers: bool, optional
        :param external_host: external_host
        :type external_host: str
        :param internal_host: internal_host
        :type internal_host: str
        :param listener_ports: listener_ports
        :type listener_ports: ListenerPortConfiguration
        :param max_number_of_threads: max_number_of_threads, defaults to None
        :type max_number_of_threads: int, optional
        :param override_url: override_url, defaults to None
        :type override_url: bool, optional
        :param protected_headers: protected_headers
        :type protected_headers: SharedWebServerProtectedHeaders
        :param ssl_certificate: ssl_certificate
        :type ssl_certificate: str
        """
        self.api_type = api_type
        self.authentication = self._define_object(
            authentication, SharedWebServerAuthentication
        )
        self.base_url = base_url
        if examine_forward_headers is not SENTINEL:
            self.examine_forward_headers = examine_forward_headers
        self.external_host = external_host
        self.internal_host = internal_host
        self.listener_ports = self._define_object(
            listener_ports, ListenerPortConfiguration
        )
        if max_number_of_threads is not SENTINEL:
            self.max_number_of_threads = max_number_of_threads
        if override_url is not SENTINEL:
            self.override_url = override_url
        self.protected_headers = self._define_object(
            protected_headers, SharedWebServerProtectedHeaders
        )
        self.ssl_certificate = ssl_certificate
        self._kwargs = kwargs




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .processing_group_trading_partner import ProcessingGroupTradingPartner


@JsonMap({"trading_partner": "TradingPartner"})
class ProcessingGroupTradingPartners(BaseModel):
    """ProcessingGroupTradingPartners

    :param trading_partner: trading_partner, defaults to None
    :type trading_partner: List[ProcessingGroupTradingPartner], optional
    """

    def __init__(
        self, trading_partner: List[ProcessingGroupTradingPartner] = SENTINEL, **kwargs
    ):
        """ProcessingGroupTradingPartners

        :param trading_partner: trading_partner, defaults to None
        :type trading_partner: List[ProcessingGroupTradingPartner], optional
        """
        if trading_partner is not SENTINEL:
            self.trading_partner = self._define_list(
                trading_partner, ProcessingGroupTradingPartner
            )
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({"account_group_id": "accountGroupId", "account_id": "accountId", "id_": "id"})
class AccountGroupAccount(BaseModel):
    """AccountGroupAccount

    :param account_group_id: The ID of the account group., defaults to None
    :type account_group_id: str, optional
    :param account_id: The ID of the account., defaults to None
    :type account_id: str, optional
    :param id_: The object’s conceptual ID from which the account and account group IDs synthesizes., defaults to None
    :type id_: str, optional
    """

    def __init__(
        self,
        account_group_id: str = SENTINEL,
        account_id: str = SENTINEL,
        id_: str = SENTINEL,
        **kwargs
    ):
        """AccountGroupAccount

        :param account_group_id: The ID of the account group., defaults to None
        :type account_group_id: str, optional
        :param account_id: The ID of the account., defaults to None
        :type account_id: str, optional
        :param id_: The object’s conceptual ID from which the account and account group IDs synthesizes., defaults to None
        :type id_: str, optional
        """
        if account_group_id is not SENTINEL:
            self.account_group_id = account_group_id
        if account_id is not SENTINEL:
            self.account_id = account_id
        if id_ is not SENTINEL:
            self.id_ = id_
        self._kwargs = kwargs




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .environment_map_extensions_summary_simple_expression import (
    EnvironmentMapExtensionsSummarySimpleExpression,
)
from .environment_map_extensions_summary_grouping_expression import (
    EnvironmentMapExtensionsSummaryGroupingExpression,
)


class EnvironmentMapExtensionsSummaryExpressionGuard(OneOfBaseModel):
    class_list = {
        "EnvironmentMapExtensionsSummarySimpleExpression": EnvironmentMapExtensionsSummarySimpleExpression,
        "EnvironmentMapExtensionsSummaryGroupingExpression": EnvironmentMapExtensionsSummaryGroupingExpression,
    }


EnvironmentMapExtensionsSummaryExpression = Union[
    EnvironmentMapExtensionsSummarySimpleExpression,
    EnvironmentMapExtensionsSummaryGroupingExpression,
]




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel


@JsonMap({})
class AsyncToken(BaseModel):
    """AsyncToken

    :param token: token
    :type token: str
    """

    def __init__(self, token: str, **kwargs):
        """AsyncToken

        :param token: token
        :type token: str
        """
        self.token = token
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..odette_connector_record import OdetteConnectorRecordService
from ...models import (
    OdetteConnectorRecordQueryResponse,
    OdetteConnectorRecordQueryConfig,
)


class OdetteConnectorRecordServiceAsync(OdetteConnectorRecordService):
    """
    Async Wrapper for OdetteConnectorRecordServiceAsync
    """

    def query_odette_connector_record(
        self, request_body: OdetteConnectorRecordQueryConfig = None
    ) -> Awaitable[Union[OdetteConnectorRecordQueryResponse, str]]:
        return to_async(super().query_odette_connector_record)(request_body)

    def query_more_odette_connector_record(
        self, request_body: str
    ) -> Awaitable[Union[OdetteConnectorRecordQueryResponse, str]]:
        return to_async(super().query_more_odette_connector_record)(request_body)




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .role_expression import RoleExpression, RoleExpressionGuard
from .role_simple_expression import RoleSimpleExpression
from .role_grouping_expression import RoleGroupingExpression


@JsonMap({})
class RoleQueryConfigQueryFilter(BaseModel):
    """RoleQueryConfigQueryFilter

    :param expression: expression
    :type expression: RoleExpression
    """

    def __init__(self, expression: RoleExpression, **kwargs):
        """RoleQueryConfigQueryFilter

        :param expression: expression
        :type expression: RoleExpression
        """
        self.expression = RoleExpressionGuard.return_one_of(expression)
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class RoleQueryConfig(BaseModel):
    """RoleQueryConfig

    :param query_filter: query_filter
    :type query_filter: RoleQueryConfigQueryFilter
    """

    def __init__(self, query_filter: RoleQueryConfigQueryFilter, **kwargs):
        """RoleQueryConfig

        :param query_filter: query_filter
        :type query_filter: RoleQueryConfigQueryFilter
        """
        self.query_filter = self._define_object(
            query_filter, RoleQueryConfigQueryFilter
        )
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .execution_count_account_group_expression import (
    ExecutionCountAccountGroupExpression,
    ExecutionCountAccountGroupExpressionGuard,
)
from .execution_count_account_group_simple_expression import (
    ExecutionCountAccountGroupSimpleExpression,
)
from .execution_count_account_group_grouping_expression import (
    ExecutionCountAccountGroupGroupingExpression,
)


@JsonMap({})
class ExecutionCountAccountGroupQueryConfigQueryFilter(BaseModel):
    """ExecutionCountAccountGroupQueryConfigQueryFilter

    :param expression: expression
    :type expression: ExecutionCountAccountGroupExpression
    """

    def __init__(self, expression: ExecutionCountAccountGroupExpression, **kwargs):
        """ExecutionCountAccountGroupQueryConfigQueryFilter

        :param expression: expression
        :type expression: ExecutionCountAccountGroupExpression
        """
        self.expression = ExecutionCountAccountGroupExpressionGuard.return_one_of(
            expression
        )
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class ExecutionCountAccountGroupQueryConfig(BaseModel):
    """ExecutionCountAccountGroupQueryConfig

    :param query_filter: query_filter
    :type query_filter: ExecutionCountAccountGroupQueryConfigQueryFilter
    """

    def __init__(
        self, query_filter: ExecutionCountAccountGroupQueryConfigQueryFilter, **kwargs
    ):
        """ExecutionCountAccountGroupQueryConfig

        :param query_filter: query_filter
        :type query_filter: ExecutionCountAccountGroupQueryConfigQueryFilter
        """
        self.query_filter = self._define_object(
            query_filter, ExecutionCountAccountGroupQueryConfigQueryFilter
        )
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .map_extension_browse import MapExtensionBrowse


@JsonMap(
    {
        "destination_browse": "DestinationBrowse",
        "source_browse": "SourceBrowse",
        "container_id": "containerId",
    }
)
class MapExtensionBrowseSettings(BaseModel):
    """Represents the Connection information and is used to re-import newly-appended profile fields. This attribute is only applicable for certain application Connectors. To perform a re-import, the client must use the EXECUTE operation. For more information, see the Customizing profiles section later in this topic.

     **Note:** `containerId` is a required field when using BrowseSettings.

    :param destination_browse: destination_browse
    :type destination_browse: MapExtensionBrowse
    :param source_browse: source_browse
    :type source_browse: MapExtensionBrowse
    :param container_id: container_id, defaults to None
    :type container_id: str, optional
    """

    def __init__(
        self,
        destination_browse: MapExtensionBrowse,
        source_browse: MapExtensionBrowse,
        container_id: str = SENTINEL,
        **kwargs,
    ):
        """Represents the Connection information and is used to re-import newly-appended profile fields. This attribute is only applicable for certain application Connectors. To perform a re-import, the client must use the EXECUTE operation. For more information, see the Customizing profiles section later in this topic.

         **Note:** `containerId` is a required field when using BrowseSettings.

        :param destination_browse: destination_browse
        :type destination_browse: MapExtensionBrowse
        :param source_browse: source_browse
        :type source_browse: MapExtensionBrowse
        :param container_id: container_id, defaults to None
        :type container_id: str, optional
        """
        self.destination_browse = self._define_object(
            destination_browse, MapExtensionBrowse
        )
        self.source_browse = self._define_object(source_browse, MapExtensionBrowse)
        if container_id is not SENTINEL:
            self.container_id = container_id
        self._kwargs = kwargs




from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class ContentTransferEncoding(Enum):
    """An enumeration representing different categories.

    :cvar BINARY: "binary"
    :vartype BINARY: str
    :cvar BASE64: "base64"
    :vartype BASE64: str
    """

    BINARY = "binary"
    BASE64 = "base64"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, ContentTransferEncoding._member_map_.values())
        )


class RosettaNetMessageOptionsEncryptionAlgorithm(Enum):
    """An enumeration representing different categories.

    :cvar NA: "na"
    :vartype NA: str
    :cvar TRIPLEDES: "tripledes"
    :vartype TRIPLEDES: str
    :cvar DES: "des"
    :vartype DES: str
    :cvar RC2_128: "rc2-128"
    :vartype RC2_128: str
    :cvar RC2_64: "rc2-64"
    :vartype RC2_64: str
    :cvar RC2_40: "rc2-40"
    :vartype RC2_40: str
    :cvar AES128: "aes-128"
    :vartype AES128: str
    :cvar AES192: "aes-192"
    :vartype AES192: str
    :cvar AES256: "aes-256"
    :vartype AES256: str
    """

    NA = "na"
    TRIPLEDES = "tripledes"
    DES = "des"
    RC2_128 = "rc2-128"
    RC2_64 = "rc2-64"
    RC2_40 = "rc2-40"
    AES128 = "aes-128"
    AES192 = "aes-192"
    AES256 = "aes-256"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                RosettaNetMessageOptionsEncryptionAlgorithm._member_map_.values(),
            )
        )


class SignatureDigestAlgorithm(Enum):
    """An enumeration representing different categories.

    :cvar SHA1: "SHA1"
    :vartype SHA1: str
    :cvar SHA224: "SHA224"
    :vartype SHA224: str
    :cvar SHA256: "SHA256"
    :vartype SHA256: str
    :cvar SHA384: "SHA384"
    :vartype SHA384: str
    :cvar SHA512: "SHA512"
    :vartype SHA512: str
    """

    SHA1 = "SHA1"
    SHA224 = "SHA224"
    SHA256 = "SHA256"
    SHA384 = "SHA384"
    SHA512 = "SHA512"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, SignatureDigestAlgorithm._member_map_.values())
        )


@JsonMap(
    {
        "attachment_cache": "attachmentCache",
        "content_transfer_encoding": "contentTransferEncoding",
        "encrypt_service_header": "encryptServiceHeader",
        "encryption_algorithm": "encryptionAlgorithm",
        "signature_digest_algorithm": "signatureDigestAlgorithm",
    }
)
class RosettaNetMessageOptions(BaseModel):
    """RosettaNetMessageOptions

    :param attachment_cache: attachment_cache, defaults to None
    :type attachment_cache: str, optional
    :param compressed: compressed, defaults to None
    :type compressed: bool, optional
    :param content_transfer_encoding: content_transfer_encoding, defaults to None
    :type content_transfer_encoding: ContentTransferEncoding, optional
    :param encrypt_service_header: encrypt_service_header, defaults to None
    :type encrypt_service_header: bool, optional
    :param encrypted: encrypted, defaults to None
    :type encrypted: bool, optional
    :param encryption_algorithm: encryption_algorithm, defaults to None
    :type encryption_algorithm: RosettaNetMessageOptionsEncryptionAlgorithm, optional
    :param signature_digest_algorithm: signature_digest_algorithm, defaults to None
    :type signature_digest_algorithm: SignatureDigestAlgorithm, optional
    :param signed: signed, defaults to None
    :type signed: bool, optional
    """

    def __init__(
        self,
        attachment_cache: str = SENTINEL,
        compressed: bool = SENTINEL,
        content_transfer_encoding: ContentTransferEncoding = SENTINEL,
        encrypt_service_header: bool = SENTINEL,
        encrypted: bool = SENTINEL,
        encryption_algorithm: RosettaNetMessageOptionsEncryptionAlgorithm = SENTINEL,
        signature_digest_algorithm: SignatureDigestAlgorithm = SENTINEL,
        signed: bool = SENTINEL,
        **kwargs
    ):
        """RosettaNetMessageOptions

        :param attachment_cache: attachment_cache, defaults to None
        :type attachment_cache: str, optional
        :param compressed: compressed, defaults to None
        :type compressed: bool, optional
        :param content_transfer_encoding: content_transfer_encoding, defaults to None
        :type content_transfer_encoding: ContentTransferEncoding, optional
        :param encrypt_service_header: encrypt_service_header, defaults to None
        :type encrypt_service_header: bool, optional
        :param encrypted: encrypted, defaults to None
        :type encrypted: bool, optional
        :param encryption_algorithm: encryption_algorithm, defaults to None
        :type encryption_algorithm: RosettaNetMessageOptionsEncryptionAlgorithm, optional
        :param signature_digest_algorithm: signature_digest_algorithm, defaults to None
        :type signature_digest_algorithm: SignatureDigestAlgorithm, optional
        :param signed: signed, defaults to None
        :type signed: bool, optional
        """
        if attachment_cache is not SENTINEL:
            self.attachment_cache = attachment_cache
        if compressed is not SENTINEL:
            self.compressed = compressed
        if content_transfer_encoding is not SENTINEL:
            self.content_transfer_encoding = self._enum_matching(
                content_transfer_encoding,
                ContentTransferEncoding.list(),
                "content_transfer_encoding",
            )
        if encrypt_service_header is not SENTINEL:
            self.encrypt_service_header = encrypt_service_header
        if encrypted is not SENTINEL:
            self.encrypted = encrypted
        if encryption_algorithm is not SENTINEL:
            self.encryption_algorithm = self._enum_matching(
                encryption_algorithm,
                RosettaNetMessageOptionsEncryptionAlgorithm.list(),
                "encryption_algorithm",
            )
        if signature_digest_algorithm is not SENTINEL:
            self.signature_digest_algorithm = self._enum_matching(
                signature_digest_algorithm,
                SignatureDigestAlgorithm.list(),
                "signature_digest_algorithm",
            )
        if signed is not SENTINEL:
            self.signed = signed
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .cross_reference_inputs import CrossReferenceInputs
from .cross_reference_outputs import CrossReferenceOutputs


@JsonMap(
    {
        "inputs": "Inputs",
        "outputs": "Outputs",
        "lookup_table_id": "lookupTableId",
        "skip_if_no_inputs": "skipIfNoInputs",
    }
)
class MapExtensionsCrossReferenceLookup(BaseModel):
    """MapExtensionsCrossReferenceLookup

    :param inputs: inputs
    :type inputs: CrossReferenceInputs
    :param outputs: outputs
    :type outputs: CrossReferenceOutputs
    :param lookup_table_id: lookup_table_id, defaults to None
    :type lookup_table_id: str, optional
    :param skip_if_no_inputs: skip_if_no_inputs, defaults to None
    :type skip_if_no_inputs: bool, optional
    """

    def __init__(
        self,
        inputs: CrossReferenceInputs,
        outputs: CrossReferenceOutputs,
        lookup_table_id: str = SENTINEL,
        skip_if_no_inputs: bool = SENTINEL,
        **kwargs,
    ):
        """MapExtensionsCrossReferenceLookup

        :param inputs: inputs
        :type inputs: CrossReferenceInputs
        :param outputs: outputs
        :type outputs: CrossReferenceOutputs
        :param lookup_table_id: lookup_table_id, defaults to None
        :type lookup_table_id: str, optional
        :param skip_if_no_inputs: skip_if_no_inputs, defaults to None
        :type skip_if_no_inputs: bool, optional
        """
        self.inputs = self._define_object(inputs, CrossReferenceInputs)
        self.outputs = self._define_object(outputs, CrossReferenceOutputs)
        if lookup_table_id is not SENTINEL:
            self.lookup_table_id = lookup_table_id
        if skip_if_no_inputs is not SENTINEL:
            self.skip_if_no_inputs = skip_if_no_inputs
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({})
class CrossReferenceRow(BaseModel):
    """CrossReferenceRow

    :param ref1: ref1, defaults to None
    :type ref1: str, optional
    :param ref10: ref10, defaults to None
    :type ref10: str, optional
    :param ref11: ref11, defaults to None
    :type ref11: str, optional
    :param ref12: ref12, defaults to None
    :type ref12: str, optional
    :param ref13: ref13, defaults to None
    :type ref13: str, optional
    :param ref14: ref14, defaults to None
    :type ref14: str, optional
    :param ref15: ref15, defaults to None
    :type ref15: str, optional
    :param ref16: ref16, defaults to None
    :type ref16: str, optional
    :param ref17: ref17, defaults to None
    :type ref17: str, optional
    :param ref18: ref18, defaults to None
    :type ref18: str, optional
    :param ref19: ref19, defaults to None
    :type ref19: str, optional
    :param ref2: ref2, defaults to None
    :type ref2: str, optional
    :param ref20: ref20, defaults to None
    :type ref20: str, optional
    :param ref3: ref3, defaults to None
    :type ref3: str, optional
    :param ref4: ref4, defaults to None
    :type ref4: str, optional
    :param ref5: ref5, defaults to None
    :type ref5: str, optional
    :param ref6: ref6, defaults to None
    :type ref6: str, optional
    :param ref7: ref7, defaults to None
    :type ref7: str, optional
    :param ref8: ref8, defaults to None
    :type ref8: str, optional
    :param ref9: ref9, defaults to None
    :type ref9: str, optional
    """

    def __init__(
        self,
        ref1: str = SENTINEL,
        ref10: str = SENTINEL,
        ref11: str = SENTINEL,
        ref12: str = SENTINEL,
        ref13: str = SENTINEL,
        ref14: str = SENTINEL,
        ref15: str = SENTINEL,
        ref16: str = SENTINEL,
        ref17: str = SENTINEL,
        ref18: str = SENTINEL,
        ref19: str = SENTINEL,
        ref2: str = SENTINEL,
        ref20: str = SENTINEL,
        ref3: str = SENTINEL,
        ref4: str = SENTINEL,
        ref5: str = SENTINEL,
        ref6: str = SENTINEL,
        ref7: str = SENTINEL,
        ref8: str = SENTINEL,
        ref9: str = SENTINEL,
        **kwargs
    ):
        """CrossReferenceRow

        :param ref1: ref1, defaults to None
        :type ref1: str, optional
        :param ref10: ref10, defaults to None
        :type ref10: str, optional
        :param ref11: ref11, defaults to None
        :type ref11: str, optional
        :param ref12: ref12, defaults to None
        :type ref12: str, optional
        :param ref13: ref13, defaults to None
        :type ref13: str, optional
        :param ref14: ref14, defaults to None
        :type ref14: str, optional
        :param ref15: ref15, defaults to None
        :type ref15: str, optional
        :param ref16: ref16, defaults to None
        :type ref16: str, optional
        :param ref17: ref17, defaults to None
        :type ref17: str, optional
        :param ref18: ref18, defaults to None
        :type ref18: str, optional
        :param ref19: ref19, defaults to None
        :type ref19: str, optional
        :param ref2: ref2, defaults to None
        :type ref2: str, optional
        :param ref20: ref20, defaults to None
        :type ref20: str, optional
        :param ref3: ref3, defaults to None
        :type ref3: str, optional
        :param ref4: ref4, defaults to None
        :type ref4: str, optional
        :param ref5: ref5, defaults to None
        :type ref5: str, optional
        :param ref6: ref6, defaults to None
        :type ref6: str, optional
        :param ref7: ref7, defaults to None
        :type ref7: str, optional
        :param ref8: ref8, defaults to None
        :type ref8: str, optional
        :param ref9: ref9, defaults to None
        :type ref9: str, optional
        """
        if ref1 is not SENTINEL:
            self.ref1 = ref1
        if ref10 is not SENTINEL:
            self.ref10 = ref10
        if ref11 is not SENTINEL:
            self.ref11 = ref11
        if ref12 is not SENTINEL:
            self.ref12 = ref12
        if ref13 is not SENTINEL:
            self.ref13 = ref13
        if ref14 is not SENTINEL:
            self.ref14 = ref14
        if ref15 is not SENTINEL:
            self.ref15 = ref15
        if ref16 is not SENTINEL:
            self.ref16 = ref16
        if ref17 is not SENTINEL:
            self.ref17 = ref17
        if ref18 is not SENTINEL:
            self.ref18 = ref18
        if ref19 is not SENTINEL:
            self.ref19 = ref19
        if ref2 is not SENTINEL:
            self.ref2 = ref2
        if ref20 is not SENTINEL:
            self.ref20 = ref20
        if ref3 is not SENTINEL:
            self.ref3 = ref3
        if ref4 is not SENTINEL:
            self.ref4 = ref4
        if ref5 is not SENTINEL:
            self.ref5 = ref5
        if ref6 is not SENTINEL:
            self.ref6 = ref6
        if ref7 is not SENTINEL:
            self.ref7 = ref7
        if ref8 is not SENTINEL:
            self.ref8 = ref8
        if ref9 is not SENTINEL:
            self.ref9 = ref9
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..as2_connector_record import As2ConnectorRecordService
from ...models import As2ConnectorRecordQueryResponse, As2ConnectorRecordQueryConfig


class As2ConnectorRecordServiceAsync(As2ConnectorRecordService):
    """
    Async Wrapper for As2ConnectorRecordServiceAsync
    """

    def query_as2_connector_record(
        self, request_body: As2ConnectorRecordQueryConfig = None
    ) -> Awaitable[Union[As2ConnectorRecordQueryResponse, str]]:
        return to_async(super().query_as2_connector_record)(request_body)

    def query_more_as2_connector_record(
        self, request_body: str
    ) -> Awaitable[Union[As2ConnectorRecordQueryResponse, str]]:
        return to_async(super().query_more_as2_connector_record)(request_body)




from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class Respagencycode(Enum):
    """An enumeration representing different categories.

    :cvar T: "T"
    :vartype T: str
    :cvar X: "X"
    :vartype X: str
    """

    T = "T"
    X = "X"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, Respagencycode._member_map_.values()))


@JsonMap({"gs_version": "gsVersion"})
class GsControlInfo(BaseModel):
    """GsControlInfo

    :param applicationcode: applicationcode, defaults to None
    :type applicationcode: str, optional
    :param gs_version: gs_version, defaults to None
    :type gs_version: str, optional
    :param respagencycode: respagencycode, defaults to None
    :type respagencycode: Respagencycode, optional
    """

    def __init__(
        self,
        applicationcode: str = SENTINEL,
        gs_version: str = SENTINEL,
        respagencycode: Respagencycode = SENTINEL,
        **kwargs
    ):
        """GsControlInfo

        :param applicationcode: applicationcode, defaults to None
        :type applicationcode: str, optional
        :param gs_version: gs_version, defaults to None
        :type gs_version: str, optional
        :param respagencycode: respagencycode, defaults to None
        :type respagencycode: Respagencycode, optional
        """
        if applicationcode is not SENTINEL:
            self.applicationcode = applicationcode
        if gs_version is not SENTINEL:
            self.gs_version = gs_version
        if respagencycode is not SENTINEL:
            self.respagencycode = self._enum_matching(
                respagencycode, Respagencycode.list(), "respagencycode"
            )
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..x12_connector_record import X12ConnectorRecordService
from ...models import X12ConnectorRecordQueryResponse, X12ConnectorRecordQueryConfig


class X12ConnectorRecordServiceAsync(X12ConnectorRecordService):
    """
    Async Wrapper for X12ConnectorRecordServiceAsync
    """

    def query_x12_connector_record(
        self, request_body: X12ConnectorRecordQueryConfig = None
    ) -> Awaitable[Union[X12ConnectorRecordQueryResponse, str]]:
        return to_async(super().query_x12_connector_record)(request_body)

    def query_more_x12_connector_record(
        self, request_body: str
    ) -> Awaitable[Union[X12ConnectorRecordQueryResponse, str]]:
        return to_async(super().query_more_x12_connector_record)(request_body)




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..atom_as2_artifacts import AtomAs2ArtifactsService
from ...models import LogDownload, AtomAs2Artifacts


class AtomAs2ArtifactsServiceAsync(AtomAs2ArtifactsService):
    """
    Async Wrapper for AtomAs2ArtifactsServiceAsync
    """

    def create_atom_as2_artifacts(
        self, request_body: AtomAs2Artifacts = None
    ) -> Awaitable[Union[LogDownload, str]]:
        return to_async(super().create_atom_as2_artifacts)(request_body)

    def download_atom_as2_artifacts(
        self,
        request_body: AtomAs2Artifacts = None,
        max_retries: int = 10,
        initial_delay: float = 2.0,
    ) -> Awaitable[bytes]:
        return to_async(super().download_atom_as2_artifacts)(
            request_body, max_retries, initial_delay
        )




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .environment_simple_expression import EnvironmentSimpleExpression
from .environment_grouping_expression import EnvironmentGroupingExpression


class EnvironmentExpressionGuard(OneOfBaseModel):
    class_list = {
        "EnvironmentSimpleExpression": EnvironmentSimpleExpression,
        "EnvironmentGroupingExpression": EnvironmentGroupingExpression,
    }


EnvironmentExpression = Union[
    EnvironmentSimpleExpression, EnvironmentGroupingExpression
]




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .hl7_connector_record_simple_expression import Hl7ConnectorRecordSimpleExpression
from .hl7_connector_record_grouping_expression import (
    Hl7ConnectorRecordGroupingExpression,
)


class Hl7ConnectorRecordExpressionGuard(OneOfBaseModel):
    class_list = {
        "Hl7ConnectorRecordSimpleExpression": Hl7ConnectorRecordSimpleExpression,
        "Hl7ConnectorRecordGroupingExpression": Hl7ConnectorRecordGroupingExpression,
    }


Hl7ConnectorRecordExpression = Union[
    Hl7ConnectorRecordSimpleExpression, Hl7ConnectorRecordGroupingExpression
]
